betty.extension.webpack.build module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.webpack.build module

Perform Webpack builds.

class betty.extension.webpack.build.Builder

  Bases: `object`

  Build Webpack assets.

  __init__(working_directory_path: Path, entry_point_providers: Sequence[WebpackEntryPointProvider & Extension], debug: bool, renderer: Renderer, *, job_context: Context, localizer: Localizer) → None
  async build() → Path

    Build the Webpack assets.

    Returns:

      The path to the directory from which the assets can be copied to their final destination.

betty.extension.webpack.build.webpack_build_id(entry_point_providers: Sequence[WebpackEntryPointProvider & Extension], debug: bool) → str

  Generate the ID for a Webpack build.